<?php
/**
 * Corponess Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function corponess_pro_customize_register( $wp_customize ) {
	$options = corponess_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'corponess_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'corponess_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'corponess-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'corponess_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'corponess_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'corponess-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'corponess_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'corponess_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'corponess-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'corponess-pro' ),
			'show-all'     => esc_html__( 'Show All', 'corponess-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'corponess-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'corponess-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'corponess-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'corponess-pro' ),
			)
	) );

	$wp_customize->add_setting( 'corponess_pro_theme_options[theme_version]', array(
		'default'           => $options['theme_version'],
		'sanitize_callback' => 'corponess_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[theme_version]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Theme Version', 'corponess-pro' ),
		'choices'  => array(
			'lite-version'   => esc_html__( 'Lite Version', 'corponess-pro' ),
            'dark-version'     => esc_html__( 'Dark Version', 'corponess-pro' ),
		),
		'section'  => 'colors',
	) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'corponess_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'corponess_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'corponess-pro' ),
		'choices'  => array(
			'default'   => esc_html__( 'Default', 'corponess-pro' ),
            'black'     => esc_html__( 'Black', 'corponess-pro' ),
            'green'     => esc_html__( 'Green', 'corponess-pro' ),
            'red'       => esc_html__( 'Red', 'corponess-pro' ),
            'violet'    => esc_html__( 'Violet', 'corponess-pro' ),
            'custom'    => esc_html__( 'Custom', 'corponess-pro' ),
		),
		'section'  => 'colors',
	) );

	$wp_customize->add_setting( 'corponess_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'corponess_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'corponess_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','corponess-pro' ),
	    'description'=> esc_html__( 'Corponess Pro Theme Options.', 'corponess-pro' ),
	    'priority'   => 150,
	) );

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// breadcrumb
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'corponess_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','corponess-pro' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'corponess-pro' ),
	    'priority'   => 140,
	) );

	require get_template_directory() . '/inc/customizer/sections/home-layout.php';

	// load topbar option
	require get_template_directory() . '/inc/customizer/sections/topbar.php';

	if ( $options['home_layout'] == 'first-design' ) {
		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';
		
		// load client option
		require get_template_directory() . '/inc/customizer/sections/client.php';

		// load course option
		require get_template_directory() . '/inc/customizer/sections/project.php';

		// load feature option
		require get_template_directory() . '/inc/customizer/sections/feature.php';

		// load cta option
		require get_template_directory() . '/inc/customizer/sections/cta.php';

		// load team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

		// load subscribe option
		require get_template_directory() . '/inc/customizer/sections/subscribe.php';
	}

	if ( $options['home_layout'] == 'second-design' || $options['home_layout'] == 'fourth-design' ) {
		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		// load cta option
		require get_template_directory() . '/inc/customizer/sections/cta.php';

		// load course option
		require get_template_directory() . '/inc/customizer/sections/project.php';

		// load feature option
		require get_template_directory() . '/inc/customizer/sections/feature.php';

		// load team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';
		
		// load client option
		require get_template_directory() . '/inc/customizer/sections/client.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load subscribe option
		require get_template_directory() . '/inc/customizer/sections/subscribe.php';
	}

	if ( $options['home_layout'] == 'third-design' ) {

		require get_template_directory() . '/inc/customizer/sections/slider.php';

		require get_template_directory() . '/inc/customizer/sections/about.php';

		require get_template_directory() . '/inc/customizer/sections/cta.php';

		require get_template_directory() . '/inc/customizer/sections/service.php';

		require get_template_directory() . '/inc/customizer/sections/client.php';

		require get_template_directory() . '/inc/customizer/sections/project.php';

		require get_template_directory() . '/inc/customizer/sections/feature.php';

		require get_template_directory() . '/inc/customizer/sections/team.php';

		require get_template_directory() . '/inc/customizer/sections/testimonial.php';
		
		require get_template_directory() . '/inc/customizer/sections/blog.php';

		require get_template_directory() . '/inc/customizer/sections/subscribe.php';
	}

	if ( $options['home_layout'] == 'fifth-design' ) {

		require get_template_directory() . '/inc/customizer/sections/slider.php';

		require get_template_directory() . '/inc/customizer/sections/about.php';

		require get_template_directory() . '/inc/customizer/sections/cta.php';

		require get_template_directory() . '/inc/customizer/sections/team.php';

		require get_template_directory() . '/inc/customizer/sections/feature.php';		
		
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

	if ( $options['home_layout'] == 'sixth-design' ) {

		require get_template_directory() . '/inc/customizer/sections/popular.php';

		require get_template_directory() . '/inc/customizer/sections/featured.php';

		require get_template_directory() . '/inc/customizer/sections/recent.php';

		require get_template_directory() . '/inc/customizer/sections/most-view.php';

		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}
	

}
add_action( 'customize_register', 'corponess_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function corponess_pro_customize_preview_js() {
	wp_enqueue_script( 'corponess-pro-customizer', get_template_directory_uri() . '/assets/js/customizer' . corponess_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'corponess_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function corponess_pro_customize_control_js() {
	// fontawesome
	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome' . corponess_pro_min() . '.css' );
	
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . corponess_pro_min() . '.css' );
	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . corponess_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	// simple icon picker
	wp_enqueue_style( 'simple-iconpicker-css', get_template_directory_uri() . '/assets/css/simple-iconpicker' . corponess_pro_min() . '.css' );
	wp_enqueue_script( 'jquery-simple-iconpicker', get_template_directory_uri() . '/assets/js/simple-iconpicker' . corponess_pro_min() . '.js', array( 'jquery' ), '', true );

	wp_enqueue_style( 'corponess-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . corponess_pro_min() . '.css' );
	wp_enqueue_script( 'corponess-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . corponess_pro_min() . '.js', array(), '1.0', true );
	$corponess_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'corponess-pro' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'corponess-pro-customize-controls', 'corponess_pro_reset_data', $corponess_pro_reset_data );
}
add_action( 'customize_controls_enqueue_scripts', 'corponess_pro_customize_control_js' );

if ( !function_exists( 'corponess_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function corponess_pro_reset_options() {
		$options = corponess_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'corponess_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'corponess_pro_reset_options' );
