<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 * @return array An array of default values
 */

function corponess_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$corponess_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#2e2e36',
		'header_tagline_color'			=> '#5c5f6b',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#007aff',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'first-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'corponess-pro' ), '[the-year]', '[site-link]' ),
		'footer_social_enable'			=> true,
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,service,about,client,project,feature,cta,team,testimonial,blog,subscribe',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'corponess-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		'nav_search_enable'				=> true,

		// topbar
		'topbar_section_enable'			=> true,
		'social_menu_enable'			=> true,
		'topbar_btn_title'				=> esc_html__( 'Apply', 'corponess-pro' ),
		'topbar_btn_url'				=> esc_html__( '#', 'corponess-pro' ),
		'topbar_field_1'				=> esc_html__( ' 123 456 7891', 'corponess-pro' ),
		'topbar_field_2'				=> esc_html__( ' support@corponess.com', 'corponess-pro' ),
		
		// slider search
		'slider_section_enable'			=> true,
		'slider_content_type'			=> 'page',
		'slider_autoplay'				=> false,
		'slider_count'					=> 3,
		'slider_title'					=> esc_html__( 'Are you ready to join', 'corponess-pro' ),
		'slider_btn_label'				=> esc_html__( 'Learn More', 'corponess-pro' ),
		'slider_alt_btn_label'			=> esc_html__( 'Apply Now', 'corponess-pro' ),
		'project_form'					=> false,

		//service 
		'service_section_enable'		=> true,
		'service_content_type'			=> 'page',
		'service_title'					=> esc_html__( 'Simple & Easy Services', 'corponess-pro' ),
		'service_sub_title'				=> esc_html__( 'Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start.', 'corponess-pro' ),
		'service_btn_label'				=> esc_html__( 'Explore all services', 'corponess-pro' ),
		'service_count'					=> 3,
		'service_column_layout'			=> 'col-3',
		'service_content_icon_1'		=> esc_html__( 'fa-mortar-board', 'corponess-pro' ),
		'service_content_icon_2'		=> esc_html__( 'fa-user', 'corponess-pro' ),
		'service_content_icon_3'		=> esc_html__( 'fa-book', 'corponess-pro' ),

		//about 
		'about_section_enable'		=> true,
		'about_content_type'		=> 'page',
		'about_title'				=> esc_html__( 'About Us', 'corponess-pro' ),
		'about_description'			=> esc_html__( 'Get know about us', 'corponess-pro' ),
		'about_btn_title'			=> esc_html__( 'Learn More', 'corponess-pro' ),

		//project 
		'project_section_enable'	=> true,
		'project_content_type'		=> 'page',
		'project_count'				=> 4,
		'project_title'				=> esc_html__( 'Our Featured projects', 'corponess-pro' ),
		'project_sub_title'			=> esc_html__( 'College is a time where you want to figure out what you are going to do with your life. At the beginning of major, your idea of career is hypothetical.', 'corponess-pro' ),
		'project_btn_title'			=> esc_html__( 'View All Project', 'corponess-pro' ),

		//feature 
		'feature_section_enable'		=> true,
		'feature_content_type'			=> 'page',
		'feature_btn_label'				=> esc_html__( 'Explore all features', 'corponess-pro' ),
		'feature_count'					=> 2,
		'feature_btn_label'				=> esc_html__( 'Lean More', 'corponess-pro' ),

		//cta 
		'cta_section_enable'		=> true,
		'cta_content_type'			=> 'custom',
		'cta_title'					=> esc_html__( 'We were simply born to paint pixels for a living', 'corponess-pro' ),
		'cta_content'				=> esc_html__( 'In start-ups you might dive directly into the work. In less than a few hours you get the source files, a shared drive link, a few simple tasks and there you go — you will learn while working.', 'corponess-pro' ),
		'cta_image'					=> esc_url( get_template_directory_uri() . '/assets/uploads/call-to-action.jpg' ),

		//team 
		'team_section_enable'				=> true,
		'team_content_type'					=> 'page',
		'team_count'						=> 4,
		'team_column_layout'				=> 'col-4',
		'team_title'						=> esc_html__( 'Our Creative Team', 'corponess-pro' ),
		'team_sub_title'					=> esc_html__( 'Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start and terrified.', 'corponess-pro' ),	
		'team_btn_label'					=> esc_html__( 'View All Team', 'corponess-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'page',
		'blog_event_enable'				=> false,
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'Latest News', 'corponess-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Articles', 'corponess-pro' ),
		'blog_event_title'				=> esc_html__( 'Upcoming Events', 'corponess-pro' ),
		'blog_event_btn_title'			=> esc_html__( 'View All Events', 'corponess-pro' ),
		'blog_event_count'				=> 3,
		'blog_content_event_type'		=> 'page',

		// popular
		'popular_section_enable'			=> true,
		'popular_content_type'				=> 'post',
		'popular_count'					=> 3,
		'popular_title'					=> esc_html__( 'Latest News', 'corponess-pro' ),

		// featured
		'featured_section_enable'			=> true,
		'featured_content_type'				=> 'post',
		'featured_count'					=> 4,
		'featured_title'					=> esc_html__( 'Latest News', 'corponess-pro' ),

		// recent
		'recent_section_enable'			=> true,
		'recent_content_type'				=> 'post',
		'recent_count'					=> 3,
		'recent_title'					=> esc_html__( 'Latest News', 'corponess-pro' ),

		// most_view
		'most_view_section_enable'			=> true,
		'most_view_content_type'				=> 'post',
		'most_view_count'					=> 2,
		'most_view_title'					=> esc_html__( 'Latest News', 'corponess-pro' ),

	

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',
		'counter_content_icon_1'		=> esc_html__( 'fa-user', 'corponess-pro' ),
		'counter_title_1'				=> esc_html__( 'Students', 'corponess-pro' ),
		'counter_number_1'				=> esc_html__( '1500+', 'corponess-pro' ),
		'counter_content_icon_2'		=> esc_html__( 'fa-book', 'corponess-pro' ),
		'counter_title_2'				=> esc_html__( 'All projects', 'corponess-pro' ),
		'counter_number_2'				=> esc_html__( '50', 'corponess-pro' ),
		'counter_content_icon_3'		=> esc_html__( 'fa-users', 'corponess-pro' ),
		'counter_title_3'				=> esc_html__( 'Certified teacher', 'corponess-pro' ),
		'counter_number_3'				=> esc_html__( '150', 'corponess-pro' ),
		'counter_content_icon_4'		=> esc_html__( 'fa-trophy', 'corponess-pro' ),
		'counter_title_4'				=> esc_html__( 'Awards wins', 'corponess-pro' ),
		'counter_number_4'				=> esc_html__( '150', 'corponess-pro' ),

		'counter_image'					=> esc_url( get_template_directory_uri() . '/assets/uploads/counter.jpg' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'page',
		'testimonial_count'				=> 4,
		'testimonial_title'				=> esc_html__( 'Client’s Testimonials', 'corponess-pro' ),
		'testimonial_sub_title'			=> esc_html__( 'Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start.', 'corponess-pro' ),
		

		// client
		'client_section_enable'			=> true,
		'client_content_type'			=> 'page',
		'client_count'					=> 4,
		'client_column_layout'			=> 'col-4',
		'client_title'					=> esc_html__( 'To our Sponsors & Partners', 'corponess-pro' ),
		'client_sub_title'				=> esc_html__( 'Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start.', 'corponess-pro' ),
		'client_image'					=> esc_url( get_template_directory_uri() . '/assets/uploads/our-sponsor.jpg' ),

		//blog 
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'page',
		'blog_title'					=> esc_html__( 'News & Announcements', 'corponess-pro' ),
		'blog_sub_title'				=> esc_html__( 'Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start and terrified.', 'corponess-pro' ),
		'blog_btn_label'				=> esc_html__( 'View All Articles', 'corponess-pro' ),
		'blog_count'					=> 3,
		'blog_column_layout'			=> 'col-3',

		'subscribe_section_enable'		=> true,
		'subscribe_title'				=> esc_html__( 'Do you have any projects?', 'corponess-pro' ),
		'subscribe_sub_title'			=> esc_html__( 'Almost two years ago I sat down in front of a computer screen, in an open office space, waiting. I was nervous, eager to start and terrified.', 'corponess-pro' ),
		'subscribe_btn_label'			=> esc_html__( 'Subscribe Now!', 'corponess-pro' ),

	);

	$output = apply_filters( 'corponess_pro_default_theme_options', $corponess_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}