<?php
/**
 * blog Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add blog section
$wp_customize->add_section( 'corponess_pro_blog_section', array(
	'title'             => esc_html__( 'Blog','corponess-pro' ),
	'description'       => esc_html__( 'Blog Section options.', 'corponess-pro' ),
	'panel'             => 'corponess_pro_front_page_panel',
) );

// blog content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'corponess-pro' ),
	'section'           => 'corponess_pro_blog_section',
	'on_off_label' 		=> corponess_pro_switch_options(),
) ) );

// blog title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_blog_section',
	'active_callback' 	=> 'corponess_pro_is_blog_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[blog_title]', array(
		'selector'            => '#latest-posts .section-header h2',
		'settings'            => 'corponess_pro_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_blog_title_partial',
    ) );
}
if ( $options['home_layout'] !== 'sixth-design' ) {
		
	// blog sub title setting and control
	$wp_customize->add_setting( 'corponess_pro_theme_options[blog_sub_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['blog_sub_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[blog_sub_title]', array(
		'label'           	=> esc_html__( 'Sub Title', 'corponess-pro' ),
		'section'        	=> 'corponess_pro_blog_section',
		'active_callback' 	=> 'corponess_pro_is_blog_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[blog_sub_title]', array(
			'selector'            => '#latest-posts .section-header p',
			'settings'            => 'corponess_pro_theme_options[blog_sub_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'corponess_pro_blog_sub_title_partial',
	    ) );
	}

	// blog content type control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[blog_column_layout]', array(
		'default'          	=> $options['blog_column_layout'],
		'sanitize_callback' => 'corponess_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[blog_column_layout]', array(
		'label'             => esc_html__( 'Column Layout', 'corponess-pro' ),
		'section'           => 'corponess_pro_blog_section',
		'type'				=> 'select',
		'active_callback' 	=> 'corponess_pro_is_blog_section_enable',
		'choices'			=> array( 
			'col-3' 		=> esc_html__( '3 Column', 'corponess-pro' ),
			'col-4' 		=> esc_html__( '4 Column', 'corponess-pro' ),
		),
	) );

	$wp_customize->add_setting( 'corponess_pro_theme_options[blog_btn_label]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['blog_btn_label'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[blog_btn_label]', array(
		'label'           	=> esc_html__( 'blog Link Label', 'corponess-pro' ),
		'section'        	=> 'corponess_pro_blog_section',
		'active_callback' 	=> 'corponess_pro_is_blog_section_enable',
		'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
	    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[blog_btn_label]', array(
			'selector'            => '#latest-posts .view-all a',
			'settings'            => 'corponess_pro_theme_options[blog_btn_label]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'corponess_pro_blog_sub_title_partial',
	    ) );
	}

	$wp_customize->add_setting( 'corponess_pro_theme_options[blog_btn_url]', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[blog_btn_url]', array(
		'label'           	=> esc_html__( 'blog Link Url', 'corponess-pro' ),
		'section'        	=> 'corponess_pro_blog_section',
		'active_callback' 	=> 'corponess_pro_is_blog_section_enable',
		'type'				=> 'url',
	) );

}

// Event social icons number control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[blog_count]', array(
	'default'          	=> $options['blog_count'],
	'sanitize_callback' => 'corponess_pro_sanitize_number_range',
	'validate_callback' => 'corponess_pro_validate_blog_count',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[blog_count]', array(
	'label'             => esc_html__( 'Number of blogs', 'corponess-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'corponess-pro' ),
	'section'           => 'corponess_pro_blog_section',
	'active_callback'   => 'corponess_pro_is_blog_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// blog content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'corponess-pro' ),
	'section'           => 'corponess_pro_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'corponess_pro_is_blog_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'corponess-pro' ),
		'post' 		=> esc_html__( 'Post', 'corponess-pro' ),
		'category' 	=> esc_html__( 'Category', 'corponess-pro' ),
		'recent' 	=> esc_html__( 'Recent', 'corponess-pro' ),
	),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
	// blog pages drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[blog_content_page_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[blog_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_blog_section',
		'choices'			=> corponess_pro_page_choices(),
		'active_callback'	=> 'corponess_pro_is_blog_section_content_page_enable',
	) ) );

	// blog posts drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[blog_content_post_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[blog_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_blog_section',
		'choices'			=> corponess_pro_post_choices(),
		'active_callback'	=> 'corponess_pro_is_blog_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'corponess_pro_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Corponess_Pro_Dropdown_Taxonomies_Control( $wp_customize,'corponess_pro_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'corponess-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'corponess-pro' ),
	'section'           => 'corponess_pro_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'corponess_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'corponess_pro_theme_options[blog_category_exclude]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Corponess_Pro_Dropdown_Category_Control( $wp_customize,'corponess_pro_theme_options[blog_category_exclude]', array(
	'label'             => esc_html__( 'Select Excluding Categories', 'corponess-pro' ),
	'description'      	=> esc_html__( 'Note: Select categories to exclude. Press Shift key select multilple categories.', 'corponess-pro' ),
	'section'           => 'corponess_pro_blog_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'corponess_pro_is_blog_section_content_recent_enable'
) ) );