<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'corponess_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','corponess-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'corponess-pro' ),
	'panel'             => 'corponess_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'corponess-pro' ),
	'section'           => 'corponess_pro_counter_section',
	'on_off_label' 		=> corponess_pro_switch_options(),
) ) );


// counter content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[counter_column]', array(
	'default'          	=> $options['counter_column'],
	'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[counter_column]', array(
	'label'             => esc_html__( 'Column Layout', 'corponess-pro' ),
	'section'           => 'corponess_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'corponess_pro_is_counter_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'corponess-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'corponess-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'corponess-pro' ),
	),
) );

$wp_customize->add_setting( 'corponess_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_image',
	'default'			=> $options['counter_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'corponess_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'corponess-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'corponess-pro' ), 1350, 385 ),
		'section'     		=> 'corponess_pro_counter_section',
		'active_callback'	=> 'corponess_pro_is_counter_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'corponess_pro_sanitize_number_range',
	'validate_callback' => 'corponess_pro_validate_counter_count',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'corponess-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'corponess-pro' ),
	'section'           => 'corponess_pro_counter_section',
	'active_callback'   => 'corponess_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter note control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['counter_content_icon_'.$i ]
	) );

	$wp_customize->add_control( new Corponess_Pro_Icon_Picker( $wp_customize, 'corponess_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_counter_section',
		'active_callback'	=> 'corponess_pro_is_counter_section_enable',
	) ) );

	// counter title setting and control
	$wp_customize->add_setting( 'corponess_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['counter_title_'.$i ]
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'corponess-pro' ), $i ),
		'section'        	=> 'corponess_pro_counter_section',
		'active_callback' 	=> 'corponess_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'corponess_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['counter_number_'.$i ]
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'corponess-pro' ), $i ),
		'section'        	=> 'corponess_pro_counter_section',
		'active_callback' 	=> 'corponess_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'corponess_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Corponess_Pro_Customize_Horizontal_Line( $wp_customize, 'corponess_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'corponess_pro_counter_section',
			'active_callback' => 'corponess_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;



