<?php
/**
 * feature Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add feature section
$wp_customize->add_section( 'corponess_pro_feature_section', array(
	'title'             => esc_html__( 'Feature','corponess-pro' ),
	'description'       => esc_html__( 'Feature Section options.', 'corponess-pro' ),
	'panel'             => 'corponess_pro_front_page_panel',
) );

// feature content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[feature_section_enable]', array(
	'default'			=> 	$options['feature_section_enable'],
	'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[feature_section_enable]', array(
	'label'             => esc_html__( 'Feature Section Enable', 'corponess-pro' ),
	'section'           => 'corponess_pro_feature_section',
	'on_off_label' 		=> corponess_pro_switch_options(),
) ) );

// Event social icons number control and settings_errors( $setting = '', $sanitize = false, $hide_on_update = false )
$wp_customize->add_setting( 'corponess_pro_theme_options[feature_count]', array(
	'default'          	=> $options['feature_count'],
	'sanitize_callback' => 'corponess_pro_sanitize_number_range',
	'validate_callback' => 'corponess_pro_validate_feature_count',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[feature_count]', array(
	'label'             => esc_html__( 'Number of Post', 'corponess-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'corponess-pro' ),
	'section'           => 'corponess_pro_feature_section',
	'active_callback'   => 'corponess_pro_is_feature_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 6,
		'style' => 'width: 100px;'
		),
) );

// feature content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[feature_content_type]', array(
	'default'          	=> $options['feature_content_type'],
	'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[feature_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'corponess-pro' ),
	'section'           => 'corponess_pro_feature_section',
	'type'				=> 'select',
	'active_callback' 	=> 'corponess_pro_is_feature_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'corponess-pro' ),
		'post' 		=> esc_html__( 'Post', 'corponess-pro' ),
		'category' 	=> esc_html__( 'Category', 'corponess-pro' ),
	),
) );

for ( $i = 1; $i <= $options['feature_count']; $i++ ) :

	$wp_customize->add_setting( 'corponess_pro_theme_options[feature_btn_label_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[feature_btn_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Feature Button %d', 'corponess-pro' ), $i ),
		'section'        	=> 'corponess_pro_feature_section',
		'active_callback' 	=> 'corponess_pro_is_feature_section_enable',
		'type'				=> 'text',
	) );
	// feature pages drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[feature_content_page_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[feature_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_feature_section',
		'choices'			=> corponess_pro_page_choices(),
		'active_callback'	=> 'corponess_pro_is_feature_section_content_page_enable',
	) ) );

	// feature posts drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[feature_content_post_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[feature_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_feature_section',
		'choices'			=> corponess_pro_post_choices(),
		'active_callback'	=> 'corponess_pro_is_feature_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'corponess_pro_theme_options[feature_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Corponess_Pro_Customize_Horizontal_Line( $wp_customize, 'corponess_pro_theme_options[feature_hr_'. $i .']',
        array(
            'section'           => 'corponess_pro_feature_section',
            'active_callback'   => 'corponess_pro_is_feature_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'corponess_pro_theme_options[feature_content_category]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Corponess_Pro_Dropdown_Taxonomies_Control( $wp_customize,'corponess_pro_theme_options[feature_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'corponess-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'corponess-pro' ),
	'section'           => 'corponess_pro_feature_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'corponess_pro_is_feature_section_content_category_enable'
) ) );