<?php
/**
 * team Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

$title = esc_html__( 'Team','corponess-pro' );
if ( $options['home_layout'] == 'fifth-design' ) {
	$title = esc_html__( 'Must Read','corponess-pro' );
}

// Add team section
$wp_customize->add_section( 'corponess_pro_team_section', array(
	'title'             => $title,
	'description'       => $title.esc_html__( ' Section options.', 'corponess-pro' ),
	'panel'             => 'corponess_pro_front_page_panel',
) );

// team content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[team_section_enable]', array(
	'label'             => $title.esc_html__( ' Section Enable', 'corponess-pro' ),
	'section'           => 'corponess_pro_team_section',
	'on_off_label' 		=> corponess_pro_switch_options(),
) ) );

// team title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_team_section',
	'active_callback' 	=> 'corponess_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[team_title]', array(
		'selector'            => '#our-team .section-header h2',
		'settings'            => 'corponess_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_team_title_partial',
    ) );
}

// team sub title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[team_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[team_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_team_section',
	'active_callback' 	=> 'corponess_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[team_sub_title]', array(
		'selector'            => '#our-team .section-header p',
		'settings'            => 'corponess_pro_theme_options[team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_team_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'corponess_pro_theme_options[team_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_btn_label'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'corponess_pro_theme_options[team_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_team_section',
	'active_callback' 	=> 'corponess_pro_is_team_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[team_btn_label]', array(
		'selector'            => '#our-team .view-all a',
		'settings'            => 'corponess_pro_theme_options[team_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_team_btn_label_partial',
    ) );
}

$wp_customize->add_setting( 'corponess_pro_theme_options[team_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[team_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_team_section',
	'active_callback' 	=> 'corponess_pro_is_team_section_enable',
	'type'				=> 'url',
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[team_count]', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'corponess_pro_sanitize_number_range',
	'validate_callback' => 'corponess_pro_validate_team_count',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[team_count]', array(
	'label'             => esc_html__( 'Number of Team', 'corponess-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'corponess-pro' ),
	'section'           => 'corponess_pro_team_section',
	'active_callback'   => 'corponess_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// team content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[team_column_layout]', array(
	'default'          	=> $options['team_column_layout'],
	'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[team_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'corponess-pro' ),
	'section'           => 'corponess_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'corponess_pro_is_team_section_enable',
	'choices'			=> array( 
		'col-3' 		=> esc_html__( '3 Column', 'corponess-pro' ),
		'col-4' 		=> esc_html__( '4 Column', 'corponess-pro' ),
	),
) );

// team content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[team_content_type]', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'corponess-pro' ),
	'section'           => 'corponess_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'corponess_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'corponess-pro' ),
		'post' 		=> esc_html__( 'Post', 'corponess-pro' ),
		'category' 	=> esc_html__( 'Category', 'corponess-pro' ),
	),
) );

for ( $i = 1; $i <= $options['team_count']; $i++ ) :
	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_team_section',
		'choices'			=> corponess_pro_page_choices(),
		'active_callback'	=> 'corponess_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_team_section',
		'choices'			=> corponess_pro_post_choices(),
		'active_callback'	=> 'corponess_pro_is_team_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'corponess_pro_theme_options[team_position_' . $i. ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[team_position_' . $i. ']', array(
		'label'           	=> sprintf( esc_html__( 'Post Text %d', 'corponess-pro' ), $i ),
		'section'        	=> 'corponess_pro_team_section',
		'active_callback' 	=> 'corponess_pro_is_team_section_enable',
		'type'				=> 'text',
	) );

	if ( $options['home_layout'] !== 'fifth-design' ) {
		
		$wp_customize->add_setting( 'corponess_pro_theme_options[team_social_' . $i. ']', array(
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new Corponess_Pro_Multi_Input_Custom_Control( $wp_customize, 'corponess_pro_theme_options[team_social_' . $i. ']', array(
			'label'             => esc_html__( 'Social Link', 'corponess-pro' ),
			'button_text'       => esc_html__( 'Add social', 'corponess-pro' ),
			'section'           => 'corponess_pro_team_section',
			'active_callback' 	=> 'corponess_pro_is_team_section_enable',
		) ) );
	}


    $wp_customize->add_setting( 'corponess_pro_theme_options[team_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Corponess_Pro_Customize_Horizontal_Line( $wp_customize, 'corponess_pro_theme_options[team_hr_'. $i .']',
        array(
            'section'           => 'corponess_pro_team_section',
            'active_callback'   => 'corponess_pro_is_team_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'corponess_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Corponess_Pro_Dropdown_Taxonomies_Control( $wp_customize,'corponess_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'corponess-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'corponess-pro' ),
	'section'           => 'corponess_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'corponess_pro_is_team_section_content_category_enable'
) ) );