<?php
/**
 * testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add testimonial section
$wp_customize->add_section( 'corponess_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','corponess-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'corponess-pro' ),
	'panel'             => 'corponess_pro_front_page_panel',
) );

// testimonial content enable control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'corponess_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Corponess_Pro_Switch_Control( $wp_customize, 'corponess_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'corponess-pro' ),
	'section'           => 'corponess_pro_testimonial_section',
	'on_off_label' 		=> corponess_pro_switch_options(),
) ) );

// testimonial title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_testimonial_section',
	'active_callback' 	=> 'corponess_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[testimonial_title]', array(
		'selector'            => '#testimonial-section .section-header h2',
		'settings'            => 'corponess_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_testimonial_title_partial',
    ) );
}

// testimonial sub title setting and control
$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[testimonial_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'corponess-pro' ),
	'section'        	=> 'corponess_pro_testimonial_section',
	'active_callback' 	=> 'corponess_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'corponess_pro_theme_options[testimonial_sub_title]', array(
		'selector'            => '#testimonial-section .section-header p',
		'settings'            => 'corponess_pro_theme_options[testimonial_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'corponess_pro_testimonial_sub_title_partial',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'corponess_pro_sanitize_number_range',
	'validate_callback' => 'corponess_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of testimonial', 'corponess-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'corponess-pro' ),
	'section'           => 'corponess_pro_testimonial_section',
	'active_callback'   => 'corponess_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// testimonial content type control and setting
$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'corponess_pro_sanitize_select',
) );

$wp_customize->add_control( 'corponess_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'corponess-pro' ),
	'section'           => 'corponess_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'corponess_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'corponess-pro' ),
		'post' 		=> esc_html__( 'Post', 'corponess-pro' ),
		'category' 	=> esc_html__( 'Category', 'corponess-pro' ),
	),
) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_testimonial_section',
		'choices'			=> corponess_pro_page_choices(),
		'active_callback'	=> 'corponess_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'corponess_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Corponess_Pro_Dropdown_Chooser( $wp_customize, 'corponess_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'corponess-pro' ), $i ),
		'section'           => 'corponess_pro_testimonial_section',
		'choices'			=> corponess_pro_post_choices(),
		'active_callback'	=> 'corponess_pro_is_testimonial_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_position_' . $i. ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'corponess_pro_theme_options[testimonial_position_' . $i. ']', array(
		'label'           	=> sprintf( esc_html__( 'Postion %d', 'corponess-pro' ), $i ),
		'section'        	=> 'corponess_pro_testimonial_section',
		'active_callback' 	=> 'corponess_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

    $wp_customize->add_setting( 'corponess_pro_theme_options[testimonial_hr_'. $i .']', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Corponess_Pro_Customize_Horizontal_Line( $wp_customize, 'corponess_pro_theme_options[testimonial_hr_'. $i .']',
        array(
            'section'           => 'corponess_pro_testimonial_section',
            'active_callback'   => 'corponess_pro_is_testimonial_section_enable',
            'type'            => 'hr'
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'corponess_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'corponess_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Corponess_Pro_Dropdown_Taxonomies_Control( $wp_customize,'corponess_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'corponess-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'corponess-pro' ),
	'section'           => 'corponess_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'corponess_pro_is_testimonial_section_content_category_enable'
) ) );