<?php
/**
 * Call to action section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage corponess Pro
 * @since corponess Pro 1.0.0
 */
if ( ! function_exists( 'corponess_pro_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since corponess Pro 1.0.0
    */
    function corponess_pro_add_cta_section() {
        $options = corponess_pro_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'corponess_pro_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'corponess_pro_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        corponess_pro_render_cta_section( $section_details );
    }
endif;

if ( ! function_exists( 'corponess_pro_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since corponess Pro 1.0.0
    * @param array $input cta section details.
    */
    function corponess_pro_get_cta_section_details( $input ) {
        $options = corponess_pro_get_theme_options();

        // Content type.
        $cta_content_type  = $options['cta_content_type'];
        
        $content = array();
        switch ( $cta_content_type ) {
            
            case 'custom':
                $custom['title']        = ! empty( $options['cta_title'] ) ? $options['cta_title'] : '';
                $custom['excerpt']       = ! empty( $options['cta_content'] ) ? $options['cta_content'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts' => true,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $cta_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = corponess_pro_trim_content( 25 );
                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'corponess_pro_filter_cta_section_details', 'corponess_pro_get_cta_section_details' );


if ( ! function_exists( 'corponess_pro_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since corponess Pro 1.0.0
   *
   */
   function corponess_pro_render_cta_section( $content_details = array() ) {
        $options = corponess_pro_get_theme_options();
        $image   = ! empty( $options['cta_image'] ) ? $options['cta_image'] : '' ;
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <?php foreach ( $content_details as $content ): ?>
            <div id="call-to-action" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ) ;?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( !empty( $options['video_link'] ) && ($options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design') || $options['home_layout'] == 'fourth-design' ): ?>
                        <div class="video-button">
                            <a href="<?php echo esc_url( $options['video_link'] ) ; ?>" class="popup-video"><?php echo corponess_pro_get_svg( array( 'icon'  => 'play' ) ) ; ?></a>
                        </div><!-- .video-button -->
                    <?php endif ?>
                    <?php if ( !empty( $content['title'] ) ): ?>
                        <header class="entry-header">
                            <h2 class="entry-title">
                                <?php echo esc_html( $content['title'] ) ; ?>
                            </h2>
                        </header>
                    <?php endif ?>
                   
                    <?php if ( !empty( $content['excerpt'] ) ): ?>
                        <div class="entry-content">
                            <p>
                                <?php echo wp_kses_post( $content['excerpt'] ) ; ?>
                            </p>
                        </div><!-- .entry-content -->
                    <?php endif ?>
                    <?php if ( !empty( $options['video_link'] ) && $options['home_layout'] == 'first-design' ): ?>
                        <div class="video-button">
                            <a href="<?php echo esc_url( $options['video_link'] ) ; ?>" class="popup-video"><?php echo corponess_pro_get_svg( array( 'icon'  => 'play' ) ) ; ?></a>
                        </div><!-- .video-button -->
                    <?php endif ?>
                </div><!-- .wrapper -->
            </div><!-- #call-to-action -->
        <?php endforeach ?>
        
    <?php }
endif;