<?php
/**
 * feature section
 *
 * This is the template for the content of feature section
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */
if ( ! function_exists( 'corponess_pro_add_feature_section' ) ) :
    /**
    * Add feature section
    *
    *@since Corponess Pro 1.0.0
    */
    function corponess_pro_add_feature_section() {
    	$options = corponess_pro_get_theme_options();
        // Check if feature is enabled on frontpage
        $feature_enable = apply_filters( 'corponess_pro_section_status', true, 'feature_section_enable' );

        if ( true !== $feature_enable ) {
            return false;
        }
        // Get feature section details
        $section_details = array();
        $section_details = apply_filters( 'corponess_pro_filter_feature_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render feature section now.
        corponess_pro_render_feature_section( $section_details );
    }
endif;

if ( ! function_exists( 'corponess_pro_get_feature_section_details' ) ) :
    /**
    * feature section details.
    *
    * @since Corponess Pro 1.0.0
    * @param array $input feature section details.
    */
    function corponess_pro_get_feature_section_details( $input ) {
        $options = corponess_pro_get_theme_options();

        // Content type.
        $feature_content_type  = $options['feature_content_type'];
        $feature_count = ! empty( $options['feature_count'] ) ? $options['feature_count'] : 3;
        
        $content = array();
        switch ( $feature_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $feature_count; $i++ ) {
                    if ( ! empty( $options['feature_content_page_' . $i] ) )
                        $page_ids[] = $options['feature_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $feature_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $feature_count; $i++ ) {
                    if ( ! empty( $options['feature_content_post_' . $i] ) )
                        $post_ids[] = $options['feature_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $feature_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['feature_content_category'] ) ? $options['feature_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $feature_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = corponess_pro_trim_content( 30 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// feature section content details.
add_filter( 'corponess_pro_filter_feature_section_details', 'corponess_pro_get_feature_section_details' );


if ( ! function_exists( 'corponess_pro_render_feature_section' ) ) :
  /**
   * Start feature section
   *
   * @return string feature content
   * @since Corponess Pro 1.0.0
   *
   */
   function corponess_pro_render_feature_section( $content_details = array() ) {
        $options = corponess_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="our-features" class="relative page-section">
            <div class="wrapper">
                <div class="section-content">
                    <?php $i = 1 ; foreach ( $content_details as $content ): ?>
                        <article class="<?php echo (! empty( $content['image'] ) ) ? 'has' : 'no' ; ?>-post-thumbnail">
                            <?php if ( ! empty( $content['image'] ) ): ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ; ?>');">
                                    <a href="#" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif ?>
                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>">
                                            <?php echo esc_html( $content['title'] ) ; ?>
                                        </a>
                                    </h2>
                                </header>

                                <div class="entry-content">
                                    <p>
                                        <?php echo esc_html( $content['excerpt'] ) ; ?>
                                    </p>
                                </div><!-- .entry-content -->

                                <?php if ( ! empty( $options['feature_btn_label_'.$i] ) ): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="btn">
                                            <?php echo esc_html( $options['feature_btn_label_'.$i] ) ; ?>
                                        </a>
                                    </div>
                                <?php endif ?>
                               
                            </div><!-- .entry-container -->
                        </article>    
                    <?php $i++ ; endforeach ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #featured-courses -->
    <?php }
endif;