<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Corponess Pro
 * @since Corponess Pro 1.0.0
 */

$options = corponess_pro_get_theme_options();


if ( ! function_exists( 'corponess_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Corponess Pro 1.0.0
	 */
	function corponess_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'corponess_pro_doctype', 'corponess_pro_doctype', 10 );


if ( ! function_exists( 'corponess_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'corponess_pro_before_wp_head', 'corponess_pro_head', 10 );

if ( ! function_exists( 'corponess_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'corponess-pro' ); ?></a>
			<div class="menu-overlay"></div>

		<?php
	}
endif;
add_action( 'corponess_pro_page_start_action', 'corponess_pro_page_start', 10 );

if ( ! function_exists( 'corponess_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'corponess_pro_page_end_action', 'corponess_pro_page_end', 10 );

if ( ! function_exists( 'corponess_pro_topbar' ) ) :
	/**
	 * Topbar html codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_topbar() { 
		$options = corponess_pro_get_theme_options(); 

		if ( $options['topbar_section_enable'] == true ): ?>
			<div id="top-bar" class="relative">
				<?php 
					echo corponess_pro_get_svg( array( 'icon' => 'up', 'class' => 'dropdown-icon' ) ); 
					echo corponess_pro_get_svg( array( 'icon' => 'down', 'class' => 'dropdown-icon' ) ); 
				?>

	            <div class="wrapper">
	                <div class="col-2 clear">
	                    <div class="hentry">
	                        <ul class="contact-info clear">
	                            <li>
	                            	<a href="<?php echo esc_url( $options['topbar_field_1'] ) ; ?>">          
	                            		<?php echo corponess_pro_get_svg( array( 'icon' => 'phone' ) ) ; ?>
		                                <?php
		                                	echo esc_html( $options['topbar_field_1'] ) ;
		                                ?>
	                               </a>
	                            </li>
	                            <li>
	                            	<a href="<?php echo esc_url( $options['topbar_field_2'] ) ; ?>">                                	         
		                                <?php echo corponess_pro_get_svg( array( 'icon' => 'message' ) ) ; ?>
		                                <?php
		                                	echo esc_html( $options['topbar_field_2'] ) ;
		                                ?>
	                               </a>
	                            </li>
	                        </ul><!-- .contact-info -->
	                    </div><!-- .hentry -->

	                    <div class="hentry">
	                        <div class="secondary-menu">
	                        	<?php if ( $options['social_menu_enable'] == true ):   
				            		$defaults = array(
				            			'theme_location' => 'social',
				            			'container' => false,
				            			'menu_class' => 'social-icons',
				            			'echo' => true,
				            			'fallback_cb' => false,
				            			'depth' => 1,
				            			'link_before' => '<span class="screen-reader-text">',
										'link_after' => '</span>',
				            		);
				            	
				            		wp_nav_menu( $defaults );
				            	endif; ?>	                            
	                        </div><!-- .secondary-menu -->
	                    </div><!-- .hentry -->
	                </div><!-- .col-2 -->
	            </div><!-- .wrapper -->
	        </div><!-- #top-bar -->
		<?php
		endif;
	}
endif;
add_action( 'corponess_pro_header_action', 'corponess_pro_topbar', 10 );

if ( ! function_exists( 'corponess_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_header_start() { ?>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'corponess_pro_header_action', 'corponess_pro_header_start', 20 );

if ( ! function_exists( 'corponess_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_site_branding() {
		$options  = corponess_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>	
		<?php if ( $options['home_layout'] == 'sixth-design' ): ?>
			<div class="site-branding-wrapper"> 
		<?php endif ?>
		
			<div class="site-branding">
				<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
				<?php } 
				if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
					<div id="site-identity">
						<?php
						if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
							if ( corponess_pro_is_latest_posts() ) : ?>
								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php else : ?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
							endif;
						} 
						if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
							$description = get_bloginfo( 'description', 'display' );
							if ( $description || is_customize_preview() ) : ?>
								<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
							<?php
							endif; 
						}?>
					</div>
		    	<?php endif; ?>
			</div><!-- .site-branding -->
			<?php if ( $options['home_layout'] == 'sixth-design' ): ?>
				<div class="site-advertisement">
	                <a href="<?php echo esc_url( $options['header_ads_link'] ) ?>"><img src="<?php echo esc_url( $options['header_ads_image'] ) ?>"></a>
	            </div><!-- .site-advertisement -->
			<?php endif ?>			
		<?php if ( $options['home_layout'] == 'sixth-design' ): ?>
			</div>
		<?php endif ?>
		<?php
	}
endif;
add_action( 'corponess_pro_header_action', 'corponess_pro_site_branding', 20 );

if ( ! function_exists( 'corponess_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_site_navigation() {
		$options = corponess_pro_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<span class="menu-label"><?php esc_html_e( 'Menu', 'corponess-pro' ); ?></span>			
				<?php
				echo corponess_pro_get_svg( array( 'icon' => 'menu' ) );
				echo corponess_pro_get_svg( array( 'icon' => 'close' ) );
				?>		
			</button>
				<?php 
					$search = '';
					if ( $options['nav_search_enable'] ) :
						$search = '<li class="search-menu">';
						$search .= '<a href="#" class="">';
						$search .= corponess_pro_get_svg( array( 'icon' => 'search' ) );
						$search .= corponess_pro_get_svg( array( 'icon' => 'close' ) );
						$search .= '</a><div id="search" style="display: none;">';
						$search .= get_search_form( $echo = false );
		                $search .= '</div></li>';
	                endif;

	        		$defaults = array(
	        			'theme_location' => 'primary',
	        			'container' => 'div',
	        			'menu_class' => 'menu nav-menu',
	        			'menu_id' => 'primary-menu',
	        			'echo' => true,
	        			'fallback_cb' => 'corponess_pro_menu_fallback_cb',
	        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
	        		);
	        	
	        		wp_nav_menu( $defaults );
	        	?>
        	</div><!-- .wrapper -->
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'corponess_pro_header_action', 'corponess_pro_site_navigation', 30 );


if ( ! function_exists( 'corponess_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_header_end() {
		?>
			
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'corponess_pro_header_action', 'corponess_pro_header_end', 50 );

if ( ! function_exists( 'corponess_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'corponess_pro_content_start_action', 'corponess_pro_content_start', 10 );

if ( ! function_exists( 'corponess_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_header_image() {
		if ( corponess_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		if ( is_singular() ) :
			$header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php corponess_pro_custom_header_banner_title(); ?></h2>
                </header>

                <?php corponess_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->
		<?php
	}
endif;
add_action( 'corponess_pro_header_image_action', 'corponess_pro_header_image', 10 );

if ( ! function_exists( 'corponess_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Corponess Pro 1.0.0
	 */
	function corponess_pro_add_breadcrumb() {
		$options = corponess_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( corponess_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list">';
				/**
				 * corponess_pro_simple_breadcrumb hook
				 *
				 * @hooked corponess_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'corponess_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;
add_action( 'corponess_pro_header_image_action', 'corponess_pro_add_breadcrumb', 20 );

if ( ! function_exists( 'corponess_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'corponess_pro_content_end_action', 'corponess_pro_content_end', 10 );

if ( ! function_exists( 'corponess_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'corponess_pro_footer', 'corponess_pro_footer_start', 10 );

if ( ! function_exists( 'corponess_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_footer_site_info() {
		$options = corponess_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info">
            <div class="wrapper">
                <span>
                	<?php 
                		echo corponess_pro_santize_allow_tag( $copyright_text ); 
                	?>
            	</span>
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'corponess_pro_footer', 'corponess_pro_footer_site_info', 40 );

if ( ! function_exists( 'corponess_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_footer_scroll_to_top() {
		$options  = corponess_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo corponess_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'corponess_pro_footer', 'corponess_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'corponess_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'corponess_pro_footer', 'corponess_pro_footer_end', 100 );

if ( ! function_exists( 'corponess_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_loader() {
		$options = corponess_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo corponess_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'corponess_pro_before_header', 'corponess_pro_loader', 10 );

if ( ! function_exists( 'corponess_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Corponess Pro 1.0.0
	 *
	 */
	function corponess_pro_infinite_loader_spinner() { 
		$id = get_the_ID();
		$options = corponess_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( ! empty( $id ) ) {
				echo '<div class="blog-loader">' . corponess_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'corponess_pro_infinite_loader_spinner_action', 'corponess_pro_infinite_loader_spinner', 10 );
